Learn R Programming

telemetR (version 1.0)

ex_rSSR: Example Renormalized Sum of Squares

Description

Example output from the `renorm_SSR()` function, calculating the renormalized sum of squares for the "survival" data found in `time_test`.

Usage

ex_rSSR

Arguments

Format

## `ex_rSSR` A data frame with 100 rows and 5 columns:

fish_type

Generally a strain, run, and species of fish (e.g. Nimbus Fall Chinook = Fall-run Chinook Salmon from Nimbus Hatchery)

mbp_n

The maximum blanking period (in seconds) used to create a set of events

SSR

The sum of squared residuals between this `mbp_n` and the next

n

the total number of events created with this `mbp_n`

rSSR

the renormalized sum of squared residuals between this `mbp_n` and the next