Learn R Programming

telemetR (version 1.0)

filter_4h: Basic Four Hit Filter for Detections

Description

This function takes a detection dataframe generated from the `add_org()` function and filters it a second time to remove any remaining multipath detections, and then check the remaining detections by comparing the time between detections, for a rolling window of 4 detections to ensure it is less 16.6x the stated pulse rate interval. Called by `second_filter()`.

Usage

filter_4h(org_file, time_unit, multipath_time, org_ping_rate)

Value

A dataframe which has been filtered to remove false positives

Arguments

org_file

a dataframe of detections retrieved from `add_org()`

time_unit

The unit of time used for analyses (secs, mins, hours, days, weeks)

multipath_time

A numeric maximum amount of time which must pass between detections for a detection to be considered a "true", not a bounced, signal.

org_ping_rate

The expected time between transmissions emitted from tags/transmitters implanted or attached to an organism

Examples

Run this code
# Apply a 4hit filter to data previously prefiltered and with organism data
filter_4h(org_file = dat_orgfilt,
          time_unit = "secs",
          multipath_time = 0.3,
          org_ping_rate = 3)

Run the code above in your browser using DataLab