Learn R Programming

telemetR (version 1.0)

raw_detections: Unfiltered detection data

Description

An example dataset of real acoustic telemetry detections of fish at several receivers within the California Central Valley from 2021. These detections have not been processed to remove false positives.

Usage

raw_detections

Arguments

Format

## `raw_detections` A data frame with 55,736 rows and 3 columns:

serial

The serial number of the detecting receiver

local_time

the local time of the detection (tz = America/Los_Angeles)

tag_id

The hexadecimal acoustic tag ID code