Example output from the `renorm_SSR()` function, calculating the renormalized sum of squares for the "survival" data found in `time_test`.
ex_rSSR## `ex_rSSR` A data frame with 100 rows and 5 columns:
Generally a strain, run, and species of fish (e.g. Nimbus Fall Chinook = Fall-run Chinook Salmon from Nimbus Hatchery)
The maximum blanking period (in seconds) used to create a set of events
The sum of squared residuals between this `mbp_n` and the next
the total number of events created with this `mbp_n`
the renormalized sum of squared residuals between this `mbp_n` and the next