opt_mbp: Idenitfy the Optimum MBP based on Convergence Threshold
Description
Takes dataframes created by `renorm_SSR()` and `conv_thresholds()` and
determines the corresponding "optimum" maximum blanking period (MBP) for each
convergence threshold.
Usage
opt_mbp(rSSR_df, thresh_values)
Value
A dataframe showing the convergence value and corresponding optimal
maximum blanking period for each grouping.
Arguments
rSSR_df
a dataframe created by created by renorm_SSRduration compare
showing the renormalized sum of squares of the residuals between one
potential blanking period and the next.
thresh_values
a dataframe created by conv_thresholds corresponding to
the chosen convergence thresholds.