An example dataset of real acoustic telemetry detections of fish at several receivers within the California Central Valley from 2021. These detections have not been processed to remove false positives.
raw_detections## `raw_detections` A data frame with 55,736 rows and 3 columns:
The serial number of the detecting receiver
the local time of the detection (tz = America/Los_Angeles)
The hexadecimal acoustic tag ID code